@@ -457,7 +457,7 @@ def main():
         help=(
             "'human' (assembly hg38) (default), 'mouse' (assembly mm39), "
             "or any of the species assemblies available at https://genome.ucsc.edu/cgi-bin/hgBlat "
-            "(use short assembly name as listed after the "/"). "
+            "(use short assembly name as listed after the '/'). "
         ),
     )
     parser_blat.add_argument(
